pub struct GetResponse {
pub current_state_version: Option<String>,
pub data: Option<String>,
pub kind: Option<String>,
pub state_key: Option<i32>,
}Expand description
This is a JSON template for an app state resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get states (response)
Fields
current_state_version: Option<String>The current app state version.
data: Option<String>The requested data.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string appstate#getResponse.
state_key: Option<i32>The key for the data.